==> am_mod_evt_0_2.zip: am_mod_evt_0_2/components/evt/template/barnraiser_01/inc/menu_event.inc.php <==
<span class="txt_highlight"><?php echo $lang['menu_label_view'];?></span>

&nbsp;

<?php
$link_css = "";
if ($page_name_short == "list") {
	$link_css = " class=\"highlight\"";
}
?>
<a href="index.php?amn=evt_list"<?php echo $link_css;?>><?php echo $lang['menu_latest'];?></a>


<?php if (isset($_SESSION['md5'])) { ?>
	&nbsp;
	
	<?php
	$link_css = "";
	if ($page_name_short == "overview") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=evt_overview"<?php echo $link_css;?>><?php echo $lang['menu_overview'];?></a>
<?php } ?>
	
&nbsp;

<?php
$link_css = "";
if ($page_name_short == "metadata") {
	$link_css = " class=\"highlight\"";
}
?>
<a href="index.php?amn=evt_metadata"<?php echo $link_css;?>><?php echo $lang['menu_cloud'];?></a>
&nbsp;

<?php if (isset($event['event_id']) && isset($_SESSION['md5'])) { ?>
	&nbsp;
	&#124;
	&nbsp;
	<span class="txt_highlight"><?php echo $lang['menu_this_event'];?></span>
	&nbsp;

	<?php
	$link_css = "";
	if ($page_name_short == "item") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=evt_item&amp;event_id=<?php echo $event['event_id']; ?>"<?php echo $link_css;?>><?php echo $lang['menu_home_page']; ?></a>
	
	
	<?php
	if (isset($event['event_start_datetime']) && date('Y-m-d H:i:s', time()) < $event['event_start_datetime']) {
	?>
	&nbsp;
	
	<?php
	$link_css = "";
	if ($page_name_short == "participate" && isset($event['event_id'])) {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=evt_participate&amp;event_id=<?php echo $event['event_id']; ?>"<?php echo $link_css;?>><?php echo $lang['menu_participation']; ?></a>
	&nbsp;
	
	<?php
	if (isset($_SESSION['user_id']) && $event['user_id'] == $_SESSION['user_id']) {
	$link_css = "";
	if ($page_name_short == "manage") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=evt_manage&amp;event_id=<?php echo $event['event_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_manage'];?></a>
	&nbsp;
	<?php }?>

	<?php
	$link_css = "";
	if ($page_name_short == "invite" && isset($event['event_id'])) {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=evt_invite&amp;event_id=<?php echo $event['event_id']; ?>"<?php echo $link_css;?>><?php echo $lang['menu_invite']; ?></a>
	<?php } ?>

	&nbsp;
<?php } ?>

&#124;
&nbsp;
<span class="txt_highlight"><?php echo $lang['menu_label_do'];?></span>
	<?php
	if (!isset($sub_section)) {
	?>
		<?php if (isset($_SESSION['md5'])) { ?>
			<?php
			if ($_SESSION['user_mod_permission'] & $resource['module']['evt']['create']) {
			?>
			&nbsp;
		
			<?php
			$link_css = "";
			if ($page_name_short == "edit") {
				$link_css = " class=\"highlight\"";
			}
			?>
			<a href="index.php?amn=evt_edit"<?php echo $link_css;?>><?php echo $lang['menu_create'];?></a>
		<?php } ?>
	<?php } ?>
<?php } ?>

&nbsp;

<?php
$link_css = "";
if ($page_name_short == "list") {
	$link_css = " class=\"highlight\"";
}
?>
<a href="index.php?amn=evt_list"<?php echo $link_css;?>><?php echo $lang['menu_search'];?></a>
<br />

==> am_mod_evt_0_4.zip: am_mod_evt_0_4/components/evt/template/barnraiser_01/inc/menu_event.inc.php <==
<span class="txt_highlight"><?php echo $lang['menu_label_view'];?></span>

&nbsp;

<?php
$link_css = "";
if ($page_name_short == "list") {
	$link_css = " class=\"highlight\"";
}
?>
<a href="index.php?amn=evt_list"<?php echo $link_css;?>><?php echo $lang['menu_latest'];?></a>


<?php if (isset($_SESSION['md5'])) { ?>
	&nbsp;
	
	<?php
	$link_css = "";
	if ($page_name_short == "overview") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=evt_overview"<?php echo $link_css;?>><?php echo $lang['menu_overview'];?></a>
<?php } ?>
	
&nbsp;

<?php
$link_css = "";
if ($page_name_short == "metadata") {
	$link_css = " class=\"highlight\"";
}
?>
<a href="index.php?amn=evt_metadata"<?php echo $link_css;?>><?php echo $lang['menu_cloud'];?></a>
&nbsp;

<?php if (isset($event['event_id']) && isset($_SESSION['md5'])) { ?>
	&nbsp;
	&#124;
	&nbsp;
	<span class="txt_highlight"><?php echo $lang['menu_this_event'];?></span>
	&nbsp;

	<?php
	$link_css = "";
	if ($page_name_short == "item") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=evt_item&amp;event_id=<?php echo $event['event_id']; ?>"<?php echo $link_css;?>><?php echo $lang['menu_home_page']; ?></a>
	
	
	<?php
	if (isset($event['event_start_datetime']) && date('Y-m-d H:i:s', time()) < $event['event_start_datetime']) {
	?>
	&nbsp;
	
	<?php
	if (isset($_SESSION['md5'])) {
	if (($event['event_type'] == $event_config['type']['membership_type']) || ($event['event_type'] != $event_config['type']['invitation'])) {
	$link_css = "";
	if ($page_name_short == "participate" && isset($event['event_id'])) {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=core_participation&amp;module_id=<?php echo $core_config['module_id']['event'];?>&amp;item_id=<?php echo $event['event_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_participation'];?></a>
	&nbsp;
	<?php }}?>


	
	
	<?php
	if (isset($participation) && $participation['participation_permission'] & $event_config['resource']['user']['allow_invite']) {
	$link_css = "";
	if ($page_name_short == "invite") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=core_invite&amp;module_id=<?php echo $core_config['module_id']['event'];?>&amp;item_id=<?php echo $event['event_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_invite'];?></a>
	&nbsp;
	<?php }?>
	
	<?php
	if (isset($_SESSION['user_id']) && $event['user_id'] == $_SESSION['user_id']) {
	$link_css = "";
	if ($page_name_short == "manage") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=evt_manage&amp;event_id=<?php echo $event['event_id'];?>"<?php echo $link_css;?>><?php echo $lang['menu_manage'];?></a>
	&nbsp;
	<?php }?>

	&nbsp;
	<?php } ?>
<?php } ?>

&#124;
&nbsp;
<span class="txt_highlight"><?php echo $lang['menu_label_do'];?></span>
	<?php
	if (!isset($sub_section)) {
	?>
		<?php if (isset($_SESSION['md5'])) { ?>
			<?php
			if ($_SESSION['user_mod_permission'] & $resource['module']['evt']['create']) {
			?>
			&nbsp;
		
			<?php
			$link_css = "";
			if ($page_name_short == "edit") {
				$link_css = " class=\"highlight\"";
			}
			?>
			<a href="index.php?amn=evt_edit"<?php echo $link_css;?>><?php echo $lang['menu_create'];?></a>
		<?php } ?>
	<?php } ?>
<?php } ?>

&nbsp;

<?php
$link_css = "";
if ($page_name_short == "list") {
	$link_css = " class=\"highlight\"";
}
?>
<a href="index.php?amn=evt_list"<?php echo $link_css;?>><?php echo $lang['menu_search'];?></a>
<br />
